| Title: | QTL Genome-Wide Composite Interval Mapping with Graphical User Interface |
|---|---|
| Description: | Conduct multiple quantitative trait loci (QTL) mapping under the framework of random-QTL-effect linear mixed model. First, each position on the genome is detected in order to obtain a negative logarithm P-value curve against genome position. Then, all the peaks on each effect (additive or dominant) curve are viewed as potential QTL, all the effects of the potential QTL are included in a multi-QTL model, their effects are estimated by empirical Bayes in doubled haploid population or by adaptive lasso in F2 population, and true QTL are identified by likelihood radio test. See Wen et al. (2018) <doi:10.1093/bib/bby058>. |
| Authors: | Zhang Ya-Wen, Wen Yang-Jun, Wang Shi-Bo, and Zhang Yuan-Ming |
| Maintainer: | Yuanming Zhang<[email protected]> |
| License: | GPL (>= 2) |
| Version: | 2.1.1 |
| Built: | 2026-05-25 10:09:23 UTC |
| Source: | https://github.com/cran/QTL.gCIMapping.GUI |
Conduct multiple quantitative trait loci (QTL) mapping under the framework of random-QTL-effect mixed linear model. First, each position on the genome is detected in order to construct a negative logarithm P-value curve against genome position. Then, all the peaks on each effect (additive or dominant) curve are viewed as potential QTL, all the effects of the potential QTL are included in a multi-QTL model, their effects are estimated by empirical Bayes in doubled haploid or by adaptive lasso in F2, and true QTL are identified by likelihood radio test.
QTL.gCIMapping.GUI()QTL.gCIMapping.GUI()
| Package: | QTL.gCIMapping.GUI |
| Type: | Package |
| Version: | 2.1.1 |
| Date: | 2020-10-8 |
| Depends: | shiny,MASS,qtl |
| Imports: | methods,openxlsx,stringr,Rcpp |
| License: | GPL version 2 or newer |
| LazyLoad: | yes |
Zhang Ya-Wen, Wen Yang-Jun, Wang Shi-Bo, Zhang Yuan-Ming
Maintainer: Yuanming Zhang<[email protected]>
An efficient multi-locus mixed model framework for the detection of small and linked QTLs in F2.Wen Yang-Jun, Zhang Ya-Wen, Zhang Jin, Feng Jian-Ying, Jim M. Dunwell, Zhang Yuan-Ming*
## Not run: QTL.gCIMapping.GUI()## Not run: QTL.gCIMapping.GUI()
GCIM format of DH genotype dataset.
data(gen)data(gen)
Dataset input of file for WangF function.
Maintainer: Yuanming Zhang<[email protected]>
GCIM format of F2 genotype dataset.
data(genf2)data(genf2)
Dataset input of file for WenF function.
Maintainer: Yuanming Zhang<[email protected]>
GCIM format of DH map dataset.
data(map)data(map)
Dataset input of file for WangF function.
Maintainer: Yuanming Zhang<[email protected]>
GCIM format of F2 map dataset.
data(mapf2)data(mapf2)
Dataset input of file for WenF function.
Maintainer: Yuanming Zhang<[email protected]>
a method that can insert marker in genotype.
markerinsert(mp,geno,map,cl,gg1,gg2,gg0,flagRIL)markerinsert(mp,geno,map,cl,gg1,gg2,gg0,flagRIL)
mp |
linkage map matrix after insert. |
geno |
genotype matrix. |
map |
linkage map matrix. |
cl |
walk speed. |
gg1 |
raw covariate matrix. |
gg2 |
code for type 1. |
gg0 |
code for missing. |
flagRIL |
RIL population or not. |
Zhang Ya-Wen, Wen Yang-Jun, Wang Shi-Bo, Zhang Yuan-Ming
Maintainer: Yuanming Zhang<[email protected]>
## Not run: mp<-matrix(c(197.9196,198.7536,199.5876,200.4216,201.2453, 202.0691,202.8928,203.7521,204.6113,205.4706,206.3298,207.1891, 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,3,3,3,3,3,3, 1,1,1,2,2,2,3,3,3,3,3,3,1,2,3,4,5,6,7,8,9,10,11,12),12,5) map<-matrix(c(1,1,1,1,197.9196,200.4216,202.8928,207.1891),4,2) geno<-matrix(c(1,99,99,99),1,4) mark_insert<-QTL.gCIMapping::markerinsert(mp,geno,map,cl=1,gg1=1,gg2=-1, gg0=99,flagRIL=1) ## End(Not run)## Not run: mp<-matrix(c(197.9196,198.7536,199.5876,200.4216,201.2453, 202.0691,202.8928,203.7521,204.6113,205.4706,206.3298,207.1891, 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,3,3,3,3,3,3, 1,1,1,2,2,2,3,3,3,3,3,3,1,2,3,4,5,6,7,8,9,10,11,12),12,5) map<-matrix(c(1,1,1,1,197.9196,200.4216,202.8928,207.1891),4,2) geno<-matrix(c(1,99,99,99),1,4) mark_insert<-QTL.gCIMapping::markerinsert(mp,geno,map,cl=1,gg1=1,gg2=-1, gg0=99,flagRIL=1) ## End(Not run)
GCIM format of DH phenotype dataset.
data(phe)data(phe)
Dataset input of file for WangF function.
Maintainer: Yuanming Zhang<[email protected]>
GCIM format of F2 phenotype dataset.
data(phef2)data(phef2)
Dataset input of file for WenF function.
Maintainer: Yuanming Zhang<[email protected]>
Genome-wide Composite Interval Mapping
WangF(pheRaw,genRaw,mapRaw1,yygg1,flagRIL,cov_en,Population,WalkSpeed,CriLOD)WangF(pheRaw,genRaw,mapRaw1,yygg1,flagRIL,cov_en,Population,WalkSpeed,CriLOD)
pheRaw |
phenotype matrix. |
genRaw |
genotype matrix. |
mapRaw1 |
linkage map matrix. |
yygg1 |
the transformed covariate matrix . |
flagRIL |
if RIL or not. |
cov_en |
raw covariate matrix. |
Population |
population flag. |
WalkSpeed |
Walk speed for Genome-wide Scanning.(WalkSpeed=1). |
CriLOD |
Critical LOD scores for significant QTL (CriLOD=2.5). |
Zhang Ya-Wen, Wen Yang-Jun, Wang Shi-Bo, Zhang Yuan-Ming
Maintainer: Yuanming Zhang<[email protected]>
## Not run: data(gen) data(phe) data(map) wf<-WangF(pheRaw=phe,genRaw=gen,mapRaw1=map,yygg1=NULL, flagRIL=0,cov_en=NULL,Population="DH",WalkSpeed=1,CriLOD=2.5) ## End(Not run)## Not run: data(gen) data(phe) data(map) wf<-WangF(pheRaw=phe,genRaw=gen,mapRaw1=map,yygg1=NULL, flagRIL=0,cov_en=NULL,Population="DH",WalkSpeed=1,CriLOD=2.5) ## End(Not run)
Genome-wide Composite Interval Mapping
WangS(flag,CriLOD,NUM,pheRaw,chrRaw_name,yygg,mx,phe,chr_name,gen, mapname,CLO)WangS(flag,CriLOD,NUM,pheRaw,chrRaw_name,yygg,mx,phe,chr_name,gen, mapname,CLO)
flag |
fix or random model. |
CriLOD |
LOD score. |
NUM |
The number of trait. |
pheRaw |
Raw phenotype matrix. |
chrRaw_name |
raw chromosome name. |
yygg |
covariate matrix. |
mx |
raw genotype matrix. |
phe |
phenotype matrix. |
chr_name |
chromosome name. |
gen |
genotype matrix. |
mapname |
linkage map matrix. |
CLO |
Number of CPUs. |
Zhang Ya-Wen, Wen Yang-Jun, Wang Shi-Bo, Zhang Yuan-Ming
Maintainer: Yuanming Zhang<[email protected]>
## Not run: data(gen) data(phe) data(map) W1re<-WangF(pheRaw=phe,genRaw=gen,mapRaw1=map,yygg1=NULL, flagRIL=0,cov_en=NULL,Population="DH",WalkSpeed=1,CriLOD=2.5) ### ws<-WangS(flag=1,CriLOD=2.5,NUM=1,pheRaw=phe, chrRaw_name=W1re$chrRaw_name,yygg=W1re$yygg,mx=W1re$mx, phe=W1re$phe,chr_name=W1re$chr_name,gen=W1re$gen, mapname=W1re$mapname,CLO=1) ## End(Not run)## Not run: data(gen) data(phe) data(map) W1re<-WangF(pheRaw=phe,genRaw=gen,mapRaw1=map,yygg1=NULL, flagRIL=0,cov_en=NULL,Population="DH",WalkSpeed=1,CriLOD=2.5) ### ws<-WangS(flag=1,CriLOD=2.5,NUM=1,pheRaw=phe, chrRaw_name=W1re$chrRaw_name,yygg=W1re$yygg,mx=W1re$mx, phe=W1re$phe,chr_name=W1re$chr_name,gen=W1re$gen, mapname=W1re$mapname,CLO=1) ## End(Not run)
An efficient multi-locus mixed model framework for the detection of small and linked QTLs in F2
WenF(pheRaw,genRaw,mapRaw1,yygg1,cov_en,WalkSpeed,CriLOD,dir)WenF(pheRaw,genRaw,mapRaw1,yygg1,cov_en,WalkSpeed,CriLOD,dir)
pheRaw |
phenotype matrix. |
genRaw |
genotype matrix. |
mapRaw1 |
linkage map matrix. |
yygg1 |
the transformed covariate matrix . |
cov_en |
raw covariate matrix. |
WalkSpeed |
Walk speed for Genome-wide Scanning.(WalkSpeed=1). |
CriLOD |
Critical LOD scores for significant QTL (CriLOD=2.5). |
dir |
file path in your computer. |
Zhang Ya-Wen, Wen Yang-Jun, Wang Shi-Bo, Zhang Yuan-Ming
Maintainer: Yuanming Zhang<[email protected]>
## Not run: data(genf2) data(phef2) data(mapf2) wf<-WenF(pheRaw=phef2,genRaw=genf2,mapRaw1=mapf2, yygg1=NULL,cov_en=NULL,WalkSpeed=1,CriLOD=2.5,dir=tempdir()) ## End(Not run)## Not run: data(genf2) data(phef2) data(mapf2) wf<-WenF(pheRaw=phef2,genRaw=genf2,mapRaw1=mapf2, yygg1=NULL,cov_en=NULL,WalkSpeed=1,CriLOD=2.5,dir=tempdir()) ## End(Not run)
An efficient multi-locus mixed model framework for the detection of small and linked QTLs in F2
WenS(flag,CriLOD,NUM,pheRaw,Likelihood,setseed,flagrqtl,yygg,mx,phe, chr_name,v.map,gen.raw,a.gen.orig,d.gen.orig,n,names.insert2,X.ad.tran.data,X.ad.t4,dir)WenS(flag,CriLOD,NUM,pheRaw,Likelihood,setseed,flagrqtl,yygg,mx,phe, chr_name,v.map,gen.raw,a.gen.orig,d.gen.orig,n,names.insert2,X.ad.tran.data,X.ad.t4,dir)
flag |
random or fix model. |
CriLOD |
LOD score. |
NUM |
the number of trait. |
pheRaw |
raw phenotype matrix . |
Likelihood |
likelihood function. |
setseed |
random seed set in which, the cross validation is needed. |
flagrqtl |
do CIM or not. |
yygg |
covariate matrix. |
mx |
raw genotype matrix. |
phe |
phenotype matrix. |
chr_name |
chromosome name. |
v.map |
linkage map matrix. |
gen.raw |
raw genotype matrix. |
a.gen.orig |
additive genotype matrix. |
d.gen.orig |
dominant genotype matrix. |
n |
number of individual. |
names.insert2 |
linkage map after insert. |
X.ad.tran.data |
genotype matrix after insert. |
X.ad.t4 |
genotype matrix. |
dir |
file storage path. |
Zhang Ya-Wen, Wen Yang-Jun, Wang Shi-Bo, Zhang Yuan-Ming
Maintainer: Yuanming Zhang<[email protected]>
## Not run: data(genf2) data(phef2) data(mapf2) WEN1re<-WenF(pheRaw=phef2,genRaw=genf2,mapRaw1=mapf2, yygg1=NULL,cov_en=NULL,WalkSpeed=1,CriLOD=2.5,dir=tempdir()) ### ws<-WenS(flag=1,CriLOD=2.5,NUM=1,pheRaw=phef2, Likelihood="REML",setseed=11001,flagrqtl=FALSE, yygg=WEN1re$yygg,mx=WEN1re$mx,phe=WEN1re$phe, chr_name=WEN1re$chr_name,v.map=WEN1re$v.map, gen.raw=WEN1re$gen.raw,a.gen.orig=WEN1re$a.gen.orig, d.gen.orig=WEN1re$d.gen.orig,n=WEN1re$n, names.insert2=WEN1re$names.insert2, X.ad.tran.data=WEN1re$X.ad.tran.data, X.ad.t4=WEN1re$X.ad.t4,dir=tempdir()) ## End(Not run)## Not run: data(genf2) data(phef2) data(mapf2) WEN1re<-WenF(pheRaw=phef2,genRaw=genf2,mapRaw1=mapf2, yygg1=NULL,cov_en=NULL,WalkSpeed=1,CriLOD=2.5,dir=tempdir()) ### ws<-WenS(flag=1,CriLOD=2.5,NUM=1,pheRaw=phef2, Likelihood="REML",setseed=11001,flagrqtl=FALSE, yygg=WEN1re$yygg,mx=WEN1re$mx,phe=WEN1re$phe, chr_name=WEN1re$chr_name,v.map=WEN1re$v.map, gen.raw=WEN1re$gen.raw,a.gen.orig=WEN1re$a.gen.orig, d.gen.orig=WEN1re$d.gen.orig,n=WEN1re$n, names.insert2=WEN1re$names.insert2, X.ad.tran.data=WEN1re$X.ad.tran.data, X.ad.t4=WEN1re$X.ad.t4,dir=tempdir()) ## End(Not run)